@@ -6,27 +6,21 @@
 /*
  * Copyright (c) 2007-2015 The OpenRC Authors.
  * See the Authors file at the top-level directory of this distribution and
- * https://github.com/OpenRC/openrc/blob/master/AUTHORS
+ * https://github.com/OpenRC/openrc/blob/HEAD/AUTHORS
  *
  * This file is part of OpenRC. It is subject to the license terms in
  * the LICENSE file found in the top-level directory of this
- * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * distribution and at https://github.com/OpenRC/openrc/blob/HEAD/LICENSE
  * This file may not be copied, modified, propagated, or distributed
  *    except according to the terms contained in the LICENSE file.
  */
 
-const char libeinfo_copyright[] = "Copyright (c) 2007-2008 Roy Marples";
-
-#include <sys/types.h>
 #include <sys/ioctl.h>
-#include <sys/stat.h>
-
 #include <errno.h>
-#include <fcntl.h>
 #include <inttypes.h>
-#include <limits.h>
 #include <stdarg.h>
 #include <stdbool.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -39,34 +33,6 @@ const char libeinfo_copyright[] = "Copyright (c) 2007-2008 Roy Marples";
 
 #include "einfo.h"
 #include "helpers.h"
-#include "hidden-visibility.h"
-
-hidden_proto(ecolor)
-hidden_proto(ebegin)
-hidden_proto(ebeginv)
-hidden_proto(ebracket)
-hidden_proto(eend)
-hidden_proto(eendv)
-hidden_proto(eerror)
-hidden_proto(eerrorn)
-hidden_proto(eerrorx)
-hidden_proto(eindent)
-hidden_proto(eindentv)
-hidden_proto(einfo)
-hidden_proto(einfon)
-hidden_proto(einfov)
-hidden_proto(einfovn)
-hidden_proto(elog)
-hidden_proto(eoutdent)
-hidden_proto(eoutdentv)
-hidden_proto(eprefix)
-hidden_proto(ewarn)
-hidden_proto(ewarnn)
-hidden_proto(ewarnv)
-hidden_proto(ewarnvn)
-hidden_proto(ewarnx)
-hidden_proto(ewend)
-hidden_proto(ewendv)
 
 /* Incase we cannot work out how many columns from ioctl, supply a default */
 #define DEFAULT_COLS		 80
@@ -182,7 +148,7 @@ static const char *const color_terms[] = {
 
 /* strlcat and strlcpy are nice, shame glibc does not define them */
 #ifdef __GLIBC__
-#  if ! defined (__UCLIBC__) && ! defined (__dietlibc__)
+#  if !defined (__UCLIBC__) && !defined (__dietlibc__)
 static size_t
 strlcat(char *dst, const char *src, size_t size)
 {
@@ -510,7 +476,6 @@ eprefix(const char *EINFO_RESTRICT prefix)
 {
 	_eprefix = prefix;
 }
-hidden_def(eprefix)
 
 static void EINFO_PRINTF(2, 0)
 elogv(int level, const char *EINFO_RESTRICT fmt, va_list ap)
@@ -537,7 +502,6 @@ elog(int level, const char *EINFO_RESTRICT fmt, ...)
 	elogv(level, fmt, ap);
 	va_end(ap);
 }
-hidden_def(elog)
 
 static int
 _eindent(FILE * EINFO_RESTRICT stream)
@@ -576,7 +540,6 @@ _ecolor(FILE * EINFO_RESTRICT f, ECOLOR color)
 			return ecolors_str[i];
 	return "";
 }
-hidden_def(ecolor)
 
 const char *
 ecolor(ECOLOR color)
@@ -643,7 +606,6 @@ einfon(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("einfon");
 	return retval;
 }
-hidden_def(einfon)
 
 int
 ewarnn(const char *EINFO_RESTRICT fmt, ...)
@@ -659,7 +621,6 @@ ewarnn(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ewarnn");
 	return retval;
 }
-hidden_def(ewarnn)
 
 int
 eerrorn(const char *EINFO_RESTRICT fmt, ...)
@@ -675,7 +636,6 @@ eerrorn(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("errorn");
 	return retval;
 }
-hidden_def(eerrorn)
 
 int
 einfo(const char *EINFO_RESTRICT fmt, ...)
@@ -692,7 +652,6 @@ einfo(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("einfo");
 	return retval;
 }
-hidden_def(einfo)
 
 int
 ewarn(const char *EINFO_RESTRICT fmt, ...)
@@ -710,24 +669,21 @@ ewarn(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ewarn");
 	return retval;
 }
-hidden_def(ewarn)
 
 void
 ewarnx(const char *EINFO_RESTRICT fmt, ...)
 {
-	int retval;
 	va_list ap;
 
 	if (fmt && !is_quiet()) {
 		va_start(ap, fmt);
 		elogv(LOG_WARNING, fmt, ap);
-		retval = _ewarnvn(fmt, ap);
+		_ewarnvn(fmt, ap);
 		va_end(ap);
-		retval += fprintf(stderr, "\n");
+		fprintf(stderr, "\n");
 	}
 	exit(EXIT_FAILURE);
 }
-hidden_def(ewarnx)
 
 int
 eerror(const char *EINFO_RESTRICT fmt, ...)
@@ -745,7 +701,6 @@ eerror(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("eerror");
 	return retval;
 }
-hidden_def(eerror)
 
 void
 eerrorx(const char *EINFO_RESTRICT fmt, ...)
@@ -761,7 +716,6 @@ eerrorx(const char *EINFO_RESTRICT fmt, ...)
 	}
 	exit(EXIT_FAILURE);
 }
-hidden_def(eerrorx)
 
 int
 ebegin(const char *EINFO_RESTRICT fmt, ...)
@@ -780,7 +734,6 @@ ebegin(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ebegin");
 	return retval;
 }
-hidden_def(ebegin)
 
 static void
 _eend(FILE * EINFO_RESTRICT fp, int col, ECOLOR color, const char *msg)
@@ -854,7 +807,6 @@ eend(int retval, const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("eend");
 	return retval;
 }
-hidden_def(eend)
 
 int
 ewend(int retval, const char *EINFO_RESTRICT fmt, ...)
@@ -869,14 +821,12 @@ ewend(int retval, const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ewend");
 	return retval;
 }
-hidden_def(ewend)
 
 void
 ebracket(int col, ECOLOR color, const char *msg)
 {
 	_eend(stdout, col, color, msg);
 }
-hidden_def(ebracket)
 
 void
 eindent(void)
@@ -898,7 +848,6 @@ eindent(void)
 	setenv("EINFO_INDENT", num, 1);
 	free(num);
 }
-hidden_def(eindent)
 
 void eoutdent(void)
 {
@@ -924,7 +873,6 @@ void eoutdent(void)
 	}
 	errno = serrno;
 }
-hidden_def(eoutdent)
 
 int
 einfovn(const char *EINFO_RESTRICT fmt, ...)
@@ -940,7 +888,6 @@ einfovn(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("einfovn");
 	return retval;
 }
-hidden_def(einfovn)
 
 int
 ewarnvn(const char *EINFO_RESTRICT fmt, ...)
@@ -956,7 +903,6 @@ ewarnvn(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ewarnvn");
 	return retval;
 }
-hidden_def(ewarnvn)
 
 int
 einfov(const char *EINFO_RESTRICT fmt, ...)
@@ -973,7 +919,6 @@ einfov(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("einfov");
 	return retval;
 }
-hidden_def(einfov)
 
 int
 ewarnv(const char *EINFO_RESTRICT fmt, ...)
@@ -990,7 +935,6 @@ ewarnv(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ewarnv");
 	return retval;
 }
-hidden_def(ewarnv)
 
 int
 ebeginv(const char *EINFO_RESTRICT fmt, ...)
@@ -1010,7 +954,6 @@ ebeginv(const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ebeginv");
 	return retval;
 }
-hidden_def(ebeginv)
 
 int
 eendv(int retval, const char *EINFO_RESTRICT fmt, ...)
@@ -1025,7 +968,6 @@ eendv(int retval, const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("eendv");
 	return retval;
 }
-hidden_def(eendv)
 
 int
 ewendv(int retval, const char *EINFO_RESTRICT fmt, ...)
@@ -1040,7 +982,6 @@ ewendv(int retval, const char *EINFO_RESTRICT fmt, ...)
 	LASTCMD("ewendv");
 	return retval;
 }
-hidden_def(ewendv)
 
 void
 eindentv(void)
@@ -1048,7 +989,6 @@ eindentv(void)
 	if (is_verbose())
 		eindent();
 }
-hidden_def(eindentv)
 
 void
 eoutdentv(void)
@@ -1056,4 +996,3 @@ eoutdentv(void)
 	if (is_verbose())
 		eoutdent();
 }
-hidden_def(eoutdentv)
