@@ -6,19 +6,30 @@
 /*
  * Copyright (c) 2007-2015 The OpenRC Authors.
  * See the Authors file at the top-level directory of this distribution and
- * https://github.com/OpenRC/openrc/blob/master/AUTHORS
+ * https://github.com/OpenRC/openrc/blob/HEAD/AUTHORS
  *
  * This file is part of OpenRC. It is subject to the license terms in
  * the LICENSE file found in the top-level directory of this
- * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * distribution and at https://github.com/OpenRC/openrc/blob/HEAD/LICENSE
  * This file may not be copied, modified, propagated, or distributed
  *    except according to the terms contained in the LICENSE file.
  */
 
+#include <errno.h>
+#include <dirent.h>
+#include <fcntl.h>
+#include <limits.h>
 #include <signal.h>
+#include <stdbool.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include "queue.h"
 #include "librc.h"
+#include "helpers.h"
 
 #if defined(__linux__) || (defined (__FreeBSD_kernel__) && defined(__GLIBC__)) \
 	|| defined(__GNU__)
@@ -129,7 +140,7 @@ rc_find_pids(const char *exec, const char *const *argv, uid_t uid, pid_t pid)
 	if (exists("/proc/self/status")) {
 		fp = fopen("/proc/self/status", "r");
 		if (fp) {
-			while (! feof(fp)) {
+			while (!feof(fp)) {
 				rc_getline(&line, &len, fp);
 				if (strncmp(line, "envID:\t0", 8) == 0) {
 					openvz_host = true;
@@ -183,12 +194,12 @@ rc_find_pids(const char *exec, const char *const *argv, uid_t uid, pid_t pid)
 			if (exists(buffer)) {
 				fp = fopen(buffer, "r");
 				free(buffer);
-				if (! fp)
+				if (!fp)
 					continue;
-				while (! feof(fp)) {
+				while (!feof(fp)) {
 					rc_getline(&line, &len, fp);
 					if (strncmp(line, "envID:", 6) == 0) {
-						container_pid = ! (strncmp(line, "envID:\t0", 8) == 0);
+						container_pid = !(strncmp(line, "envID:\t0", 8) == 0);
 						break;
 					}
 				}
