@@ -6,20 +6,35 @@
 /*
  * Copyright (c) 2007-2015 The OpenRC Authors.
  * See the Authors file at the top-level directory of this distribution and
- * https://github.com/OpenRC/openrc/blob/master/AUTHORS
+ * https://github.com/OpenRC/openrc/blob/HEAD/AUTHORS
  *
  * This file is part of OpenRC. It is subject to the license terms in
  * the LICENSE file found in the top-level directory of this
- * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * distribution and at https://github.com/OpenRC/openrc/blob/HEAD/LICENSE
  * This file may not be copied, modified, propagated, or distributed
  *    except according to the terms contained in the LICENSE file.
  */
 
-static const char librc_copyright[] = "Copyright (c) 2007-2008 Roy Marples";
+#include <helpers.h>
+#include <ctype.h>
+#include <dirent.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <libgen.h>
+#include <limits.h>
+#include <regex.h>
+#include <stdbool.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/param.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include "queue.h"
 #include "librc.h"
-#include <helpers.h>
+#include "misc.h"
+#include "rc.h"
 #ifdef __FreeBSD__
 #  include <sys/sysctl.h>
 #endif
@@ -234,7 +249,7 @@ detect_prefix(const char *systype)
 }
 
 static const char *
-detect_container(const char *systype _unused)
+detect_container(const char *systype RC_UNUSED)
 {
 #ifdef __FreeBSD__
 	if (systype) {
@@ -298,7 +313,7 @@ detect_container(const char *systype _unused)
 }
 
 static const char *
-detect_vm(const char *systype _unused)
+detect_vm(const char *systype RC_UNUSED)
 {
 #ifdef __NetBSD__
 	if (systype) {
@@ -540,10 +555,10 @@ rc_service_resolve(const char *service)
 
 	/* First check started services */
 	snprintf(file, sizeof(file), RC_SVCDIR "/%s/%s", "started", service);
-	if (lstat(file, &buf) || ! S_ISLNK(buf.st_mode)) {
+	if (lstat(file, &buf) || !S_ISLNK(buf.st_mode)) {
 		snprintf(file, sizeof(file), RC_SVCDIR "/%s/%s",
 		    "inactive", service);
-		if (lstat(file, &buf) || ! S_ISLNK(buf.st_mode))
+		if (lstat(file, &buf) || !S_ISLNK(buf.st_mode))
 			*file = '\0';
 	}
 
@@ -744,7 +759,7 @@ rc_service_mark(const char *service, const RC_SERVICE state)
 			s != RC_SERVICE_STOPPED &&
 			s != RC_SERVICE_HOTPLUGGED &&
 			s != RC_SERVICE_SCHEDULED) &&
-		    (! skip_wasinactive || s != RC_SERVICE_WASINACTIVE))
+		    (!skip_wasinactive || s != RC_SERVICE_WASINACTIVE))
 		{
 			snprintf(file, sizeof(file), RC_SVCDIR "/%s/%s",
 			    rc_service_state_names[i].name, base);
@@ -757,8 +772,10 @@ rc_service_mark(const char *service, const RC_SERVICE state)
 					    RC_SVCDIR "/%s/%s",
 					    rc_parse_service_state(RC_SERVICE_WASINACTIVE),
 					    base);
-					if (symlink(init, was) == -1)
+					if (symlink(init, was) == -1) {
+						free(init);
 						return false;
+					}
 					skip_wasinactive = true;
 				}
 				if (unlink(file) == -1) {
@@ -903,7 +920,7 @@ rc_service_schedule_start(const char *service, const char *service_to_start)
 	bool retval;
 
 	/* service may be a provided service, like net */
-	if (! service || ! rc_service_exists(service_to_start))
+	if (!service || !rc_service_exists(service_to_start))
 		return false;
 
 	p += snprintf(file, sizeof(file), RC_SVCDIR "/scheduled/%s",
@@ -949,11 +966,11 @@ rc_services_in_runlevel(const char *runlevel)
 
 #ifdef RC_PKG_INITDIR
 		TAILQ_CONCAT(list, pkg, entries);
-		free(pkg);
+		rc_stringlist_free(pkg);
 #endif
 #ifdef RC_LOCAL_INITDIR
 		TAILQ_CONCAT(list, local, entries);
-		free(local);
+		rc_stringlist_free(local);
 #endif
 		return list;
 	}
@@ -979,8 +996,9 @@ rc_services_in_runlevel_stacked(const char *runlevel)
 	TAILQ_FOREACH(stack, stacks, entries) {
 		sl = rc_services_in_runlevel(stack->value);
 		TAILQ_CONCAT(list, sl, entries);
-		free(sl);
+		rc_stringlist_free(sl);
 	}
+	rc_stringlist_free(stacks);
 	return list;
 }
 
@@ -1002,7 +1020,7 @@ rc_services_in_state(RC_SERVICE state)
 
 	dirs = ls_dir(dir, 0);
 	list = rc_stringlist_new();
-	if (! dirs)
+	if (!dirs)
 		return list;
 
 	TAILQ_FOREACH(d, dirs, entries) {
@@ -1010,7 +1028,7 @@ rc_services_in_state(RC_SERVICE state)
 		services = ls_dir(dir, LS_INITD);
 		if (services) {
 			TAILQ_CONCAT(list, services, entries);
-			free(services);
+			rc_stringlist_free(services);
 		}
 	}
 	rc_stringlist_free(dirs);
