@@ -87,6 +87,7 @@ static RC_HOOK hook_out;
 struct termios *termios_orig = NULL;
 
 RC_PIDLIST service_pids;
+RC_PIDLIST free_these_pids;
 
 static void
 clean_failed(void)
@@ -116,8 +117,7 @@ clean_failed(void)
 static void
 cleanup(void)
 {
-	RC_PID *p1 = LIST_FIRST(&service_pids);
-	RC_PID *p2;
+	RC_PID *p, *tmp;
 
 	if (!rc_in_logger && !rc_in_plugin &&
 	    applet && (strcmp(applet, "rc") == 0 || strcmp(applet, "openrc") == 0))
@@ -139,10 +139,13 @@ cleanup(void)
 		rc_logger_close();
 	}
 
-	while (p1) {
-		p2 = LIST_NEXT(p1, entries);
-		free(p1);
-		p1 = p2;
+	LIST_FOREACH_SAFE(p, &service_pids, entries, tmp) {
+		LIST_REMOVE(p, entries);
+		free(p);
+	}
+	LIST_FOREACH_SAFE(p, &free_these_pids, entries, tmp) {
+		LIST_REMOVE(p, entries);
+		free(p);
 	}
 
 	rc_stringlist_free(main_hotplugged_services);
@@ -344,22 +347,46 @@ static char *get_krunlevel(void)
 static void
 add_pid(pid_t pid)
 {
+	sigset_t sset, old;
 	RC_PID *p = xmalloc(sizeof(*p));
 	p->pid = pid;
+
+	/* this list will be accessed inside the SIGCHLD signal handler.
+	 * so we need to ensure that the SIGCHLD handler doesn't get invoked
+	 * while the list is at an inconsistent state.
+	 */
+	sigemptyset(&sset);
+	sigaddset(&sset, SIGCHLD);
+	sigprocmask(SIG_SETMASK, &sset, &old);
 	LIST_INSERT_HEAD(&service_pids, p, entries);
+	sigprocmask(SIG_SETMASK, &old, NULL);
 }
 
 static void
-remove_pid(pid_t pid)
+remove_pid(pid_t pid, bool inside_signal)
 {
-	RC_PID *p;
+	sigset_t sset, old;
+	RC_PID *p, *tmp;
 
-	LIST_FOREACH(p, &service_pids, entries)
-	    if (p->pid == pid) {
-		    LIST_REMOVE(p, entries);
-		    free(p);
-		    return;
-	    }
+	/* same rationale for blocking SIGCHLD as add_pid() */
+	sigemptyset(&sset);
+	sigaddset(&sset, SIGCHLD);
+	sigprocmask(SIG_SETMASK, &sset, &old);
+	LIST_FOREACH(p, &service_pids, entries) {
+		if (p->pid == pid) {
+			LIST_REMOVE(p, entries);
+			LIST_INSERT_HEAD(&free_these_pids, p, entries);
+			break;
+		}
+	}
+	/* only call free if we're not inside a signal handler */
+	if (!inside_signal) {
+		LIST_FOREACH_SAFE(p, &free_these_pids, entries, tmp) {
+			LIST_REMOVE(p, entries);
+			free(p);
+		}
+	}
+	sigprocmask(SIG_SETMASK, &old, NULL);
 }
 
 static void
@@ -397,7 +424,7 @@ handle_signal(int sig)
 
 		/* Remove that pid from our list */
 		if (pid > 0)
-			remove_pid(pid);
+			remove_pid(pid, true);
 		break;
 
 	case SIGWINCH:
@@ -606,7 +633,7 @@ stop:
 			add_pid(pid);
 			if (!parallel) {
 				rc_waitpid(pid);
-				remove_pid(pid);
+				remove_pid(pid, false);
 			}
 		}
 	}
@@ -672,7 +699,7 @@ do_start_services(const RC_STRINGLIST *start_services, bool parallel)
 			add_pid(pid);
 			if (!parallel) {
 				rc_waitpid(pid);
-				remove_pid(pid);
+				remove_pid(pid, false);
 			}
 		}
 	}
@@ -745,6 +772,7 @@ int main(int argc, char **argv)
 
 	applet = basename_c(argv[0]);
 	LIST_INIT(&service_pids);
+	LIST_INIT(&free_these_pids);
 	atexit(cleanup);
 	if (!applet)
 		eerrorx("arguments required");
